@@ -64,7 +64,7 @@ class MyForm(QtGui.QMainWindow):
 			# Import to use proper python sending technique
 			os.system('dbus-send --dest=org.QGVDial.TextServer --session --print-reply /org/QGVDial/TextServer org.QGVDial.TextServer.Text array:string:"' + self.number + '" string:"' + self.message + '"')
 		elif method == 1: # SIM
-			os.system('/usr/bin/smssend -n ' + self.number + ' -m "' + self.message + '"')
+			os.system('/usr/bin/smssend -c -n ' + self.number + ' -m "' + self.message + '"')
 			#print "SIM message sending not yet supported."
 		else:
 			print "Message sending method not recognized."
